@@ -17,6 +17,7 @@ from .introspection import (
     Property,
     Cardinality,
 )
+from .enums import PropertyCardinality
 
 
 class DBVendor(str, Enum):
@@ -31,6 +32,7 @@ class PropertyConfig(BaseModel):
     module_path: str
     module_name: str
     validate_as_basemodel: bool = True
+    cardinality: PropertyCardinality = PropertyCardinality.ONE
 
 
 class NodeConfig(BaseModel):
@@ -324,8 +326,11 @@ def build_node_and_resolver(
             f"allow_mutation={not prop.readonly and not prop.is_computed}"
         )
         if node_config and prop.name in node_config.basemodel_properties:
-            module_name = node_config.basemodel_properties[prop.name].module_name
-            type_str = prop.type_str_basemodel(module_name)
+            prop_config = node_config.basemodel_properties[prop.name]
+            module_name = prop_config.module_name
+            type_str = prop.type_str_basemodel(
+                module_name, cardinality=prop_config.cardinality
+            )
         else:
             type_str = prop.type_str
         if not (prop.is_computed or is_appendix):
